@@ -12,8 +12,8 @@ class AppEnvironmentSerializer(NetBoxModelSerializer):
 
     class Meta:
         model = AppEnvironment
-        fields = ["url", "id", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "helm",
-                  "monitoring", "postgres_monitoring", "kustomize", "ocp_project", "requests_cpu", "requests_memory",
+        fields = ["url", "id", "cluster_env", "app_env", "mtls", "repo", "branch", "access_token", "path", "egress_ip", "deployment_kind",
+                  "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory",
                   "limits_cpu", "limits_memory", "created", "last_updated", "custom_fields"]
 
 
