@@ -1,6 +1,5 @@
 from django.db import migrations, models
 import utilities.json
-from ocp_project_plugin.fields import MemoryResourceField
 
 
 class Migration(migrations.Migration):
@@ -61,7 +60,9 @@ class Migration(migrations.Migration):
                 ("branch", models.CharField(max_length=20)),
                 ("access_token", models.CharField(max_length=100)),
                 ("path", models.CharField(max_length=20)),
-                ("egress_ip", models.CharField(max_length=20)),
+                ("egress_ip",
+                 models.OneToOneField(blank=True, null=True, on_delete=models.deletion.SET_NULL,
+                                      related_name='app_env_egress_ip', to='ipam.ipaddress')),
                 ("deployment_kind", models.CharField(max_length=20)),
                 ("monitoring", models.BooleanField()),
                 ("postgres_monitoring", models.BooleanField()),
@@ -69,9 +70,9 @@ class Migration(migrations.Migration):
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="app_env_ocp_project",
                                    to="ocp_project_plugin.OCPProject")),
                 ("requests_cpu", models.CharField(max_length=5, null=True)),
-                ("requests_memory", MemoryResourceField(null=True)),
+                ("requests_memory", models.CharField(max_length=5, null=True)),
                 ("limits_cpu", models.CharField(max_length=5, null=True)),
-                ("limits_memory", MemoryResourceField(null=True)),
+                ("limits_memory", models.CharField(max_length=5, null=True)),
             ],
             options={
                 "ordering": ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
