@@ -1,10 +1,13 @@
+from django.core.validators import RegexValidator
 from django.db.models import CharField, BooleanField, ForeignKey, CASCADE, OneToOneField, SET_NULL
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
 from ocp_project_plugin.choices import AppEnvironmentClusterEnvChoices, AppEnvironmentDeploymentKindChoices
 from ocp_project_plugin.models import OCPProject
-from ocp_project_plugin.utils.gitlab import clone_repo
+
+memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
+                                                          "with Mi (Megabyte) or Gi (Gigabyte)")
 
 
 class AppEnvironment(NetBoxModel):
@@ -84,6 +87,7 @@ class AppEnvironment(NetBoxModel):
         blank=True,
         verbose_name="Memory request",
         help_text="The memory value e.g. 200Mi or 1Gi",
+        validators=[memory_validator],
     )
     limits_cpu = CharField(
         max_length=5,
