@@ -2,6 +2,7 @@ from django.db.models import CharField, ForeignKey, PROTECT
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
+from ocp_project_plugin.models import AppEnvironment
 
 
 class OCPProject(NetBoxModel):
@@ -80,3 +81,9 @@ class OCPProject(NetBoxModel):
             'request': self.request,
             'url': self.docu_url
         }
+
+    def count_app_environments(self):
+        return AppEnvironment.objects.filter(OCPProject=self).count()
+
+    def get_all_app_environments(self):
+        return AppEnvironment.objects.filter(OCPProject=self)
