@@ -29,10 +29,9 @@ class AppEnvironmentIndex(SearchIndex):
         ('branch', 100),
         ('path', 100),
         ('egress_ip', 100),
-        ('helm', 100),
+        ('deployment_kind', 100),
         ('monitoring', 100),
         ('postgres_monitoring', 100),
-        ('kustomize', 100),
         ('ocp_project', 100),
         ('requests_cpu', 100),
         ('requests_memory', 100),
